'use strict';

var Benchmark = require('benchmark');
var emojis = require('emojilib');
var nearley = require('nearley');
var emojiGrammar = require('./parsers/emoji.js');
var parsimmon = require('./parsers/emoji-parsimmon.js');
var pegjs = require('pegjs-import');
var pegjsEmoji = pegjs.buildParser('./parsers/emoji.pegjs');
var _ = require('lodash');

function nearleyParse(string) {
  var nearleyEmoji = new nearley.Parser(emojiGrammar.ParserRules,
                                        emojiGrammar.ParserStart);

  nearleyEmoji.feed(string);

  return nearleyEmoji.results;
}

var characters = _(emojis)
  .filter(function (emoji) {
    return emoji.char;
  })
  .map(function (emoji) {
    return emoji.char;
  })
  .value();

var suite = new Benchmark.Suite;

suite
  .add('PegJS', function () {
    characters.forEach(function (emoji) {
      pegjsEmoji.parse(emoji);
    });
  })
  .add('parsimmon', function () {
    characters.forEach(function (emoji) {
      parsimmon(emoji);
    });
  })
  .add('nearley.js', function () {
    characters.forEach(function (emoji) {
      nearleyParse(emoji);
    });
  })
  .on('cycle', function (event) {
    console.log(String(event.target));
  })
  .on('complete', function () {
    console.log('Fastest is ' + this.filter('fastest').pluck('name'));
  })
  .run();
